import 'package:flutter_custom_toolbox/flutter_toolbox.dart';

import 'package:petitbac/data/fetch_data_helper.dart';
import 'package:petitbac/models/data/category.dart';
import 'package:petitbac/models/data/letter.dart';
import 'package:petitbac/models/game/game_item.dart';
import 'package:petitbac/models/settings/settings_game.dart';
import 'package:petitbac/models/settings/settings_global.dart';

class Game {
  Game({
    // Settings
    required this.gameSettings,
    required this.globalSettings,

    // State
    this.isRunning = false,
    this.isStarted = false,
    this.isFinished = false,
    this.animationInProgress = false,

    // Base data
    required this.items,

    // Game data
    this.position = 0,
    this.countdown = 0,
  });

  // Settings
  final GameSettings gameSettings;
  final GlobalSettings globalSettings;

  // State
  bool isRunning;
  bool isStarted;
  bool isFinished;
  bool animationInProgress;

  // Base data
  final List<GameItem> items;

  // Game data
  int position;
  int countdown;

  factory Game.createEmpty() {
    return Game(
      gameSettings: GameSettings.createDefault(),
      globalSettings: GlobalSettings.createDefault(),
      items: [],
    );
  }

  factory Game.createNew({
    GameSettings? gameSettings,
    GlobalSettings? globalSettings,
  }) {
    final GameSettings newGameSettings = gameSettings ?? GameSettings.createDefault();
    final GlobalSettings newGlobalSettings = globalSettings ?? GlobalSettings.createDefault();

    final List<GameItem> items =
        FetchDataHelper().getRandomItems(newGameSettings.itemsCountValue);

    return Game(
      // Settings
      gameSettings: newGameSettings,
      globalSettings: newGlobalSettings,
      // State
      isRunning: true,
      isStarted: true,
      // Base data
      items: items,
    );
  }

  bool get canBeResumed => isStarted && !isFinished;

  GameItem get item => items[position];
  Category get category => item.category;
  Letter get letter => item.letter;

  void dump() {
    printlog('');
    printlog('## Current game dump:');
    printlog('');
    printlog('$Game:');
    printlog('  Settings');
    gameSettings.dump();
    globalSettings.dump();
    printlog('  State');
    printlog('    isRunning: $isRunning');
    printlog('    isStarted: $isStarted');
    printlog('    isFinished: $isFinished');
    printlog('    animationInProgress: $animationInProgress');
    printlog('  Base data');
    printlog('    items: $items');
    printlog('  Game data');
    printlog('    position: $position');
    printlog('    countdown: $countdown');
    printlog('');
  }

  @override
  String toString() {
    return '$Game(${toJson()})';
  }

  Map<String, dynamic>? toJson() {
    return <String, dynamic>{
      // Settings
      'gameSettings': gameSettings.toJson(),
      'globalSettings': globalSettings.toJson(),
      // State
      'isRunning': isRunning,
      'isStarted': isStarted,
      'isFinished': isFinished,
      'animationInProgress': animationInProgress,
      // Base data
      'items': items,
      // Game data
      'position': position,
      'countdown': countdown,
    };
  }
}
